@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2010-2012 by Daniel Nicoletti                           *
+ *   Copyright (C) 2010-2018 by Daniel Nicoletti                           *
  *   dantti12@gmail.com                                                    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -47,7 +47,7 @@ ConfigureDialog::ConfigureDialog(const QString &destName, bool isClass, QWidget
     setModal(false);
     setStandardButtons(QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::Apply);
     setWindowTitle(destName);
-    setWindowIcon(QIcon::fromTheme("configure"));
+    setWindowIcon(QIcon::fromTheme(QLatin1String("configure")));
     enableButtonApply(false);
     // Needed so we have our dialog size saved
     setAttribute(Qt::WA_DeleteOnClose);
@@ -56,7 +56,7 @@ ConfigureDialog::ConfigureDialog(const QString &destName, bool isClass, QWidget
     KPageWidgetItem *page;
 
     modifyPrinter = new ModifyPrinter(destName, isClass, this);
-    PrinterBehavior *printerBehavior = new PrinterBehavior(destName, isClass, this);
+    auto printerBehavior = new PrinterBehavior(destName, isClass, this);
     attr << modifyPrinter->neededValues();
     attr << printerBehavior->neededValues();
     attr << KCUPS_PRINTER_TYPE; // needed to know if it's a remote printer
@@ -101,9 +101,9 @@ ConfigureDialog::ConfigureDialog(const QString &destName, bool isClass, QWidget
     modifyPrinter->setValues(printer);
     page = new KPageWidgetItem(modifyPrinter, i18n("Modify Printer"));
     page->setHeader(i18n("Configure"));
-    page->setIcon(QIcon::fromTheme("dialog-information"));
+    page->setIcon(QIcon::fromTheme(QLatin1String("dialog-information")));
     // CONNECT this signal ONLY to the first Page
-    connect(modifyPrinter, SIGNAL(changed(bool)), this, SLOT(enableButtonApply(bool)));
+    connect(modifyPrinter, &ModifyPrinter::changed, this, &ConfigureDialog::enableButtonApply);
     addPage(page);
 
     if (!isClass) {
@@ -112,9 +112,9 @@ ConfigureDialog::ConfigureDialog(const QString &destName, bool isClass, QWidget
         printerOptions = new PrinterOptions(destName, isClass, isRemote, this);
         page = new KPageWidgetItem(printerOptions, i18n("Printer Options"));
         page->setHeader(i18n("Set the Default Printer Options"));
-        page->setIcon(QIcon::fromTheme("view-pim-tasks"));
+        page->setIcon(QIcon::fromTheme(QLatin1String("view-pim-tasks")));
         addPage(page);
-        connect(modifyPrinter, SIGNAL(ppdChanged()), this, SLOT(ppdChanged()));
+        connect(modifyPrinter, &ModifyPrinter::ppdChanged, this, &ConfigureDialog::ppdChanged);
         modifyPrinter->setCurrentMake(printerOptions->currentMake());
         modifyPrinter->setCurrentMakeAndModel(printerOptions->currentMakeAndModel());
     }
@@ -123,17 +123,16 @@ ConfigureDialog::ConfigureDialog(const QString &destName, bool isClass, QWidget
     printerBehavior->setValues(printer);
     page = new KPageWidgetItem(printerBehavior, i18n("Banners, Policies and Allowed Users"));
     page->setHeader(i18n("Banners, Policies and Allowed Users"));
-    page->setIcon(QIcon::fromTheme("feed-subscribe"));
+    page->setIcon(QIcon::fromTheme(QLatin1String("feed-subscribe")));
     addPage(page);
 
     // connect this after ALL pages were added, otherwise the slot will be called
-    connect(this, SIGNAL(currentPageChanged(KPageWidgetItem*,KPageWidgetItem*)),
-            SLOT(currentPageChanged(KPageWidgetItem*,KPageWidgetItem*)));
+    connect(this, &ConfigureDialog::currentPageChanged, this, &ConfigureDialog::currentPageChangedSlot);
 
-    KConfigGroup group(KSharedConfig::openConfig("print-manager"), "ConfigureDialog");
+    KConfigGroup group(KSharedConfig::openConfig(QLatin1String("print-manager")), "ConfigureDialog");
     KWindowConfig::restoreWindowSize(windowHandle(), group);
 
-    connect(buttonBox(), SIGNAL(clicked(QAbstractButton*)), this, SLOT(slotButtonClicked(QAbstractButton*)));
+    connect(buttonBox(), &QDialogButtonBox::clicked, this, &ConfigureDialog::slotButtonClicked);
 }
 
 void ConfigureDialog::ppdChanged()
@@ -145,34 +144,36 @@ void ConfigureDialog::ppdChanged()
 
 ConfigureDialog::~ConfigureDialog()
 {
-    KConfigGroup group(KSharedConfig::openConfig("print-manager"), "ConfigureDialog");
+    KConfigGroup group(KSharedConfig::openConfig(QLatin1String("print-manager")), "ConfigureDialog");
     KWindowConfig::saveWindowSize(windowHandle(), group);
 }
 
-void ConfigureDialog::currentPageChanged(KPageWidgetItem *current, KPageWidgetItem *before)
+void ConfigureDialog::currentPageChangedSlot(KPageWidgetItem *current, KPageWidgetItem *before)
 {
-    PrinterPage *currentPage = qobject_cast<PrinterPage*>(current->widget());
-    PrinterPage *beforePage = qobject_cast<PrinterPage*>(before->widget());
+    auto currentPage = qobject_cast<PrinterPage*>(current->widget());
+    auto beforePage = qobject_cast<PrinterPage*>(before->widget());
 
+    qCDebug(PM_CONFIGURE_PRINTER) << "currentPageChanged" << beforePage << currentPage;
     // Check if the before page has changes
     savePage(beforePage);
     if (beforePage) {
-        disconnect(beforePage, SIGNAL(changed(bool)), this, SLOT(enableButtonApply(bool)));
+        disconnect(beforePage, &PrinterPage::changed, this, &ConfigureDialog::enableButtonApply);
     }
 
     // connect the changed signal to the new page and check if it has changes
-    connect(currentPage, SIGNAL(changed(bool)), this, SLOT(enableButtonApply(bool)));
+    connect(currentPage, &PrinterPage::changed, this, &ConfigureDialog::enableButtonApply);
     enableButtonApply(currentPage->hasChanges());
 }
 
 void ConfigureDialog::enableButtonApply(bool enable)
 {
+    qDebug() << Q_FUNC_INFO << enable << sender();
     button(QDialogButtonBox::QDialogButtonBox::Apply)->setEnabled(enable);
 }
 
 void ConfigureDialog::slotButtonClicked(QAbstractButton * pressedButton)
 {
-    PrinterPage *page = qobject_cast<PrinterPage *>(currentPage()->widget());
+    auto page = qobject_cast<PrinterPage *>(currentPage()->widget());
     if (pressedButton == button(QDialogButtonBox::Ok) ||
         pressedButton == button(QDialogButtonBox::Apply)) {
         page->save();
@@ -181,7 +182,7 @@ void ConfigureDialog::slotButtonClicked(QAbstractButton * pressedButton)
 
 void ConfigureDialog::closeEvent(QCloseEvent *event)
 {
-    PrinterPage *page = qobject_cast<PrinterPage*>(currentPage()->widget());
+    auto page = qobject_cast<PrinterPage*>(currentPage()->widget());
     if (savePage(page)) {
         event->accept();
     } else {
@@ -204,3 +205,5 @@ bool ConfigureDialog::savePage(PrinterPage *page)
     }
     return true;
 }
+
+#include "moc_ConfigureDialog.cpp"
